Rectangle

Struct Rectangle 

pub struct Rectangle {
    pub coordinate: Coordinate,
    pub dimensions: Dimensions,
}
Rectangle defined by inclusive minimum and maximum coordinates.

let rectangle = Rectangle::from (((1, 2).into(), (5, 3).into()));
assert_eq!(rectangle.height(), 5);
assert_eq!(rectangle.width(),  3);
assert_eq!(rectangle.height(), rectangle.dimensions.rows);
assert_eq!(rectangle.width(),  rectangle.dimensions.columns);
assert_eq!(rectangle.contains ((0, 0).into()), false);
assert_eq!(rectangle.contains ((4, 3).into()), true);

Fields

coordinate: Coordinatedimensions: Dimensions

Implementations

Source

impl Rectangle

pub const fn width(&self) -> usize

pub const fn height(&self) -> usize

pub const fn min(&self) -> Coordinate

pub const fn max(&self) -> Coordinate

Max is inclusive: this is the lower right corner element of the rectangle

pub const fn upper_left(&self) -> Coordinate

pub const fn upper_right(&self) -> Coordinate

pub const fn lower_right(&self) -> Coordinate

pub const fn lower_left(&self) -> Coordinate

pub fn row(&self, row: usize) -> Option<Self>

pub fn column(&self, column: usize) -> Option<Self>

pub const fn area(&self) -> usize

Rows * columns

pub fn contains(&self, _: Coordinate) -> bool

Return true if the coordinate is between min and max (inclusive)

pub fn contains_rc(&self, row: usize, column: usize) -> bool

pub fn iter(&self) -> impl Iterator<Item = Coordinate>